@@ -1,5 +1,5 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.76';
+$App::pherkin::VERSION = '0.77';
 use strict;
 use warnings;
 
@@ -36,7 +36,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.76
+version 0.77
 
 =head1 SYNOPSIS
 
@@ -274,6 +274,7 @@ sub _process_arguments {
 
         # Standard
         help       => [ 'h|help|?' ],
+        version    => [ 'version' ],
         includes   => [ 'I=s@', [] ],
         lib        => [ 'l|lib' ],
         blib       => [ 'b|blib' ],
@@ -301,6 +302,14 @@ sub _process_arguments {
         return ( ref $value eq 'ARRAY' ) ? $value : $$value;
     };
 
+    if ( $deref->('version') ) {
+        my ($vol, $dirs, $file) = File::Spec->splitpath( $0 );
+        my $version = $App::pherkin::VERSION || '(development)';
+        print "$file $version\n";
+
+        exit 0;
+    }
+
     pod2usage(
         -verbose => 1,
         -input   => "$RealBin/$Script",
