@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::TAP;
-$Test::BDD::Cucumber::Harness::TAP::VERSION = '0.76';
+$Test::BDD::Cucumber::Harness::TAP::VERSION = '0.77';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TAP - Generate results in TAP format
 
 =head1 VERSION
 
-version 0.76
+version 0.77
 
 =head1 DESCRIPTION
 
@@ -93,7 +93,8 @@ sub step_done {
                             $self->_note_step_data($step));
             }
         } else {
-            $ctx->todo_skip($step_name, 'Step not implemented');
+            $ctx->send_event( 'Skip', todo => 'pending', todo_diag => 1,
+                              reason => 'Step not implemented', pass => 0);
             $ctx->note($self->_note_step_data($step));
         }
     } elsif ( $status eq 'passing' ) {
